#ifndef MSP430_INIT_h
#define MSP430_INIT_h

/*******************************************************************************/
/*    Pin Description                                                          */
/*                                                                             */
/*    MSP-F2013    Direction   RMF02-Module    Function  (MSP)                 */
/*                                                                             */
/*    P1IN0(IR)     <---       /IRQ     Inport for the IRQ comming from rmf02  */
/*    P1OUT1.1      --->       FSK      Output for the data to bee transmitted */
/*    P1OUT1.2      --->       /CS      Output for the Chip-Select ..          */
/*    P1OUT2.7      --->       SLK      Clock for the SPI-Interface of the ..  */
/*    P1OUT2.6      --->       SPI-SIMO Output (MOSI) for the SPI-Data-Inpute  */
/*                                                                             */
/*******************************************************************************/

//    Port config and working Registers

//    Input                     PxIN           These defines are already made 
//    Output                    PxOUT          in msp430.h or in msp430f2013.h
//    Direction                 PxDIR
//    Interrupt Flag            PxIFG
//    Interrupt Edge Select     PxIES
//    Interrupt Enable          PxIE
//    Port Select               PxSEL
//    Resistor Enable           PxREN

// After Power Up or Reset these registers have accidently values and have
// to be configured !

/******************************************************************************/
/*         Handling-Macros                                                    */
/******************************************************************************/

#define SCK_high() P2OUT |= SLK
#define SCK_low()  P2OUT &= ~SLK
#define SDI_high() P2OUT |= SDI
#define SDI_low()  P2OUT &= ~SDI
#define FSK_high() P2OUT |= FSK
#define nCS_high() P1OUT |=  nCS  // inactive
#define nCS_low()  P1OUT &= ~nCS  // active

/******************************************************************************/
/*         Modul-Interface                                                    */
/******************************************************************************/
#define nIRQ  BIT0
#define FSK   BIT1
#define nCS   BIT2
#define SDI   BIT6
#define SLK   BIT7


/******************************************************************************/
/*         Function Prototypes                                                */
/******************************************************************************/

void Init_MSP430F169( void );           // EVA-Board-Controller   o n l y
void Init_MSP430F2013_SPI_Port( void );

#endif
