/******************************************************************************/
/*         Programm-Modul mit Handling-Funktionen zur Datenbertragung        */
/*                                                                            */                
/*                                                                            */                
/* Funktionen:                                                                */                
/*                                                                            */                
/*     RFM02_CMD_Transmit_DataByte(char);   Senden von 8 Bit                  */                
/*     RFM02_CMD_Transmit_DataWord(int);    Senden von 16 Bit                 */                
/*     RFM02_CMD_Sleep(void);               Sleepmode-Aktivierung (0,3A)     */                
/*     RFM02_CMD_TransmissionWakeUp(void);  Wiederaktivierung aus dem Sleepmode */                
/*                                                                            */                
/*     RFM02_CMD_Switch_On(void);           Modul sendebereit machen          */                
/*     RFM02_CMD_Switch_Off(void);          Modul abschalten bis in Sleepmode */                
/*                                                                            */                
/*     Wait_100ms(int);                     Wartezeitfunktion fr Modulinitialisierung */                
/*                                                                            */                
/* Autor: Hr.JSchroeder@web.de          01/2012                               */                
/******************************************************************************/

/*------------------------------------------------------------------*/
/*    INCLUDES                                                      */
/*------------------------------------------------------------------*/
#include "includes.h"

/******************************************************************************/
/*         Wartefunktion fr die Modulhandhabung                              */
/*                                                                            */                
/* Autor: Hr.JSchroeder@web.de                                                */                
/******************************************************************************/
void Wait_100ms(int wert){
    while(wert--){wert++;wert--;}
}

/******************************************************************************/
/*         Handlingfunktion zum aktivieren des Moduls bis zur                 */
/*         Sendebereitschaft, d.h. Oscillator, Synthesizer, RF-Amplifier      */                
/*         werden eingeschaltet.                                              */                
/*                                                                            */                
/*         Stromaufnahme dann 22,4 mA bei max. Sendeleistung (8dbm)           */                
/*                                                                            */                
/*         Aufruf in main.c, Datenbyte wird an den SPI-Eingang bertragen     */
/*                                                                            */                
/* Autor: Hr.JSchroeder@web.de                                                */                
/******************************************************************************/
void RFM02_CMD_Switch_On(void){
int cmd_16_buffer;

  nCS_low();

/*----------------------------------------------------------------------------*/
/*  Init_RF_LowBattDet_TXBIT_Sync_And_WUT_Cal_Register                                                 */
/*----------------------------------------------------------------------------*/
    cmd_16_buffer  = CONFIG_LOW_BATT_TRESHOLD;    // Basis-Command-Value
//  cmd_16_buffer |= LOW_BATT_THLD_2_2_V;         // not used
    cmd_16_buffer |= TXBIT_SYNC;                  // Enable TX Bit Syncronisation
//  cmd_16_buffer |= DISABLE_WAKEUP_TIMER_CAL;    // not disabled

    SPI_Config_CMD_16Bit( cmd_16_buffer );    // Writing the command to the SPI-Interface

/*----------------------------------------------------------------------------*/
/*  Init_RF_Power_Management_Register                                                 */
/*----------------------------------------------------------------------------*/
  cmd_16_buffer  = CONFIG_PWR_CMD;         // Basis-Command-Value
//  cmd_16_buffer |= CLK_PIN;                // Disable ClockPin, not used for MCU
//  cmd_16_buffer |= WAKE_UP_TIMER;          // Enable/set WakeUpTimer
//  cmd_16_buffer |= LOW_BATT_DET;           // Enable Low Battery Detection
  cmd_16_buffer |= POWER_AMP;              // Activate Power Amplifier
  cmd_16_buffer |= SYNTHESSIZER;           // Activate Synthesizer
  cmd_16_buffer |= CRYSTAL_OSC;            // Activate Crystal Oscillator 
//    cmd_16_buffer |= AUTO_PWR_AMP;           // Setting AMP to Auto-Enable/Disable 
//    cmd_16_buffer |= AUTO_PWR_SYN_OSC;       // Setting Synthesizer and Oscillator to Auto-En-/Disable

    SPI_Config_CMD_16Bit( cmd_16_buffer );   // Writing the command to the SPI-Interface

  nCS_high();
}

/******************************************************************************/
/*         Handlingfunktion zum "abschalten" des Moduls,                      */
/*         d.h. Oscillator, Synthesizer, RF-Amplifier                         */                
/*         werden deaktiviert.                                                */                
/*                                                                            */                
/*         Stromaufnahme dann ??? A                                          */                
/*                                                                            */                
/*         Aufruf in main.c, Datenbyte wird an den SPI-Eingang bertragen     */
/*                                                                            */                
/* Autor: Hr.JSchroeder@web.de                                                */                
/******************************************************************************/
void RFM02_CMD_Switch_Off(void){
int cmd_16_buffer;
  nCS_low();
//  Init_RF_Power_Management_Register like in rfm01_trans_init.c

  cmd_16_buffer  = CONFIG_PWR_CMD;        // Basis-Command-Value
  cmd_16_buffer |= AUTO_PWR_AMP;          // Setting AMP to Auto-Enable/Disable 
  cmd_16_buffer |= AUTO_PWR_SYN_OSC;      // Setting Synthesizer and Oscillator to Auto-En-/Disable
  SPI_Config_CMD_16Bit( cmd_16_buffer );  // Writing the command to the SPI-Interface

  Wait_100ms(0x4000);     // wait time needet to make the sleep-command working

  RFM02_CMD_Sleep();                      // 0,3A now !!!!

  nCS_high();
}

/******************************************************************************/
/*         Handlingfunktion zum aktivieren des LowPowerModes                  */
/*                                                                            */                
/*         Aufruf in main.c, Datenbyte wird an den SPI-Eingang bertragen     */
/*                                                                            */                
/* Autor: Hr.JSchroeder@web.de                                                */                
/******************************************************************************/
void RFM02_CMD_Sleep(void){
int cmd_16_buffer;

    cmd_16_buffer  = CMD_SLEEP;               // Basis-Command-Value
    cmd_16_buffer |= CMD_SLEEP_AFTER_255_PERIODS;  

    SPI_Config_CMD_16Bit( cmd_16_buffer );    // Writing the command to the SPI-Interface
}

/******************************************************************************/
/*         Handlingfunktion zum aktivieren des Moduls im Auto-Mode            */
/*                                                                            */                
/*         Aufruf in main.c, Datenbyte wird an den SPI-Eingang bertragen     */
/*                                                                            */                
/* Autor: Hr.JSchroeder@web.de              funzt ned !!!!!!!!!!!!!1          */                
/******************************************************************************/
void RFM02_CMD_TransmissionWakeUp(void){
int cmd_16_buffer;

    cmd_16_buffer  = CMD_TRANSMIT_DATA;       // Basis-Command-Value

    SPI_Config_CMD_16Bit( cmd_16_buffer );    // Writing the command to the SPI-Interface

}

/******************************************************************************/
/*         Handlingfunktion fr das Senden eines Datenbytes                   */
/*                                                                            */                
/*         Aufruf in main.c, Datenbyte wird an den Eingang FSK bertragen     */
/*                                                                            */                
/*         Entsprechend der eingestellten Baudrate wird am nIRQ-Ausgang       */                
/*         ein kurzer High-Impuls ausgegeben.                                 */                
/*         nIRQ ist somit in Wirklichkeit ein Datarate-Clock-Ausgang,         */                
/*         und zwar ein eins-aktiver !!!                                      */                
/*         Beim Schreiben auf FSK wird also Clock low, abgewartet, dann ein   */                
/*         Bit geschrieben und auf  0->1  und 1->0 gewartet.                  */                
/*         Der Ausgang hat berhaupt nichts mit einer nIRQ-Funktionalitt     */                
/*         zu tun !!!!                                                        */                
/* Autor: Hr.JSchroeder@web.de                                                */                
/******************************************************************************/
void RFM02_CMD_Transmit_DataByte (char DataByte){
char n=8;
nCS_low();
  while(n--){               // ... make 8 times (for bit0 ... bit7)

    while(P1IN & nIRQ);     // if IRQ is high, wait until low

    if( DataByte & BIT7 )   // Writing Bit corresponding to its value in the data byte.
      P1OUT |= FSK;         // ...write '1' if most significant bit is '1'
    else
      P1OUT &= ~FSK;        // ... or write '0' if .... is '0'


    while(!(P1IN & nIRQ));  // wait for the next high-pulse, corresponding to the
                            // adjusted Baud-Rate...

    DataByte <<= 1;         // shift DataByte one bit left to write the next bit
  }
nCS_high();
}

/******************************************************************************/
/*         Handlingfunktion fr das Senden eines 2 Datenbytes langen          */
/*         DatenWortes.                                                        */                
/*                                                                            */                
/*         Entsprechend der eingestellten Baudrate wird am nIRQ-Ausgang       */                
/*         ein kurzer High-Impuls ausgegeben.                                 */                
/*         nIRQ ist somit in Wirklichkeit ein Datarate-Clock-Ausgang,         */                
/*         und zwar ein eins-aktiver !!!                                      */                
/*         Beim Schreiben auf FSK wird also auf Clock low getestet, ggf.abge- */                
/*         wartet,dann der Wert fr das Bit angelegt                          */                
/*         und auf  nIRQ  0->1 (Datenbernahme) gewartet.                     */                
/*                                                                            */                
/*         Der Ausgang hat nicht wirklich etwas mit einer nIRQ-Funktionalitt */                
/*         zu tun, sondern stellt vielmehr einen DatenClock dar.              */                
/*                                                                            */                
/* Autor: Hr.JSchroeder@web.de                                                */                
/******************************************************************************/
void RFM02_CMD_Transmit_DataWord(int DataWord){
char n=16;
nCS_low();
  while(n--){               // ... make 8 times (for bit0 ... bit7)

    while(P1IN & nIRQ);     // if IRQ is high, wait until low

    if( DataWord & BIT7 )   // Writing Bit corresponding to its value in the DataWord.
      P1OUT |= FSK;         // ...write '1' if most significant bit is '1'
    else
      P1OUT &= ~FSK;        // ... or write '0' if .... is '0'


    while(!(P1IN & nIRQ));  // wait for the next high-pulse, corresponding to the
                            // adjusted Baud-Rate...

    DataWord <<= 1;         // shift DataWord one bit left to write the next bit
  }
nCS_high();
}




