/******************************************************************************/
/*         Programm-Modul mit allen Initialisierungsfunktionen                */
/*                                                                            */                
/*         die fr die Initialisierung des Sendemoduls bentigt werden.       */
/*                                                                            */                
/*  Funktionen                                                                */                
/*                                                                            */                
/*        Init_RFM02_Transmit_Module_Continous_Mode (void);                   */                
/*                                                                            */                
/*        SPI_Config_CMD_16Bit (int);                                                                    */                
/*                                                                            */                
/* Autor: Hr.JSchroeder@web.de          01/2012                               */                
/******************************************************************************/

/*----------------------------------------------------------------------------*/
/*    INCLUDES                                                                */
/*----------------------------------------------------------------------------*/
#include "includes.h"


/*----------------------------------------------------------------------------*/
/*    FUNCTIONS                                                               */
/*----------------------------------------------------------------------------*/


/******************************************************************************/
/*         Hauptfunktion fr die Initialisierung des Sendmoduls               */
/*                                                                            */                
/*         Aufruf in main.c bei Programmstart, nach der MCU-Initialisierung   */
/*                                                                            */                
/* Autor: Hr.JSchroeder@web.de                                                */                
/******************************************************************************/
void Init_RFM02_Transmit_Module_Continous_Mode(void){
int cmd_16_buffer;

/*----------------------------------------------------------------------------*/
/*  Init_RF_Config_Register                                                   */
//  - keine Angabe fr die Dimensionierung  der Load-Capacity ???
//  - BandSelectbytes nicht in jeder Doku dokumentiert
//  - in der Modulanleitung wird ein undokumentierter Befehl (0xCC00) verwendet ?????
//  - 
/*-----------------------------------------------------------------------------*/
    cmd_16_buffer  = CONFIG_CMD;              // Basis-Command-Value
    cmd_16_buffer |= FREQ_DEV_120kHz;         // Setting Frequency Deviation
//  cmd_16_buffer |= MOD_POLTY_180_NEG;       // Setting Modulation Polarity negative
    cmd_16_buffer |= CRYSTAL_LD_CAP_10_0PF;   // Setting Crystal Load Capacity
    cmd_16_buffer |= CLK_PIN_FREQ_10_00MHZ;   // Setting Clock-Pin-Frequency
    cmd_16_buffer |= BAND_SELECT_433MHz;      // Setting the RF-Band !!!!

    SPI_Config_CMD_16Bit( cmd_16_buffer );    // Writing the command to the SPI-Interface

/*----------------------------------------------------------------------------*/
/*  Init_RF_Frequency_Adjust_Register                                         */
//  - Einstellung funktioniert leider nicht entsprechend Dokumentation
//  - Die Werte drfen dabei von 0x0060 bis maximal 0x0F3F liegen. Auerhalb
//    dieses Bereiches springt die Sendefrequenz auf ihren Band-Grundwert,
//    d.h. 435 MHz bzw. 870 MHz  bzw. 360 MHz bzw. 915MHz
/*----------------------------------------------------------------------------*/
    cmd_16_buffer  = CONFIG_RF_FREQUENY_CMD;  // Basis-Command-Value
    cmd_16_buffer |= RF_FRQUENCY_439_9000_MHZ;// corresponding to the defines in *.h

    SPI_Config_CMD_16Bit( cmd_16_buffer );    // Writing the command to the SPI-Interface

/*----------------------------------------------------------------------------*/
/*  Init_RF_Baudrate_Adjust_Register                                          */
//     - bei 115000 bps konnte ich leider nur knapp 9kbps messen/besttigen
//     - in der Modul-Anleitung taucht hier ein undokumentierter Befehl auf,
//       der einen Vorteiler einstellt 0xD040  // Datarate/2   ??????
/*----------------------------------------------------------------------------*/
    cmd_16_buffer  = CONFIG_BAUD_RATE_CMD;    // Basis-Command-Value
    cmd_16_buffer |= BAUD_RATE_38_400_BPS;    // corresponding to the defines in *.h
                                              // BAUD_RATE_445_000_BPS (gemessen !!!)
                                              // BAUD_RATE_172_000_BPS (gemessen !!!)
                                              // BAUD_RATE_115_000_BPS
                                              // BAUD_RATE_38_400_BPS
                                              // BAUD_RATE_19_200_BPS
                                              // BAUD_RATE_04_800_BPS
                                              
    SPI_Config_CMD_16Bit( cmd_16_buffer );    // Writing the command to the SPI-Interface

/*----------------------------------------------------------------------------*/
/*  Init_RF_Power_Register                                                    */
//   - angegebene Formel ist falsch, lsst sich aber von 0 bis 8 dbm einstellen
/*----------------------------------------------------------------------------*/
    cmd_16_buffer  = CONFIG_RF_PWR_CMD;       // Basis-Command-Value
    cmd_16_buffer |= RF_PWR_8DBM;             // Setting RF-Power to maximum

    SPI_Config_CMD_16Bit ( cmd_16_buffer );    // Writing the command to the SPI-Interface

/*----------------------------------------------------------------------------*/
/*  Init_RF_LowBattDet_TXBIT_Sync_And_WUT_Cal_Register                        */
//     - leider unzureichend dokumentiert
/*----------------------------------------------------------------------------*/
    cmd_16_buffer  = CONFIG_LOW_BATT_TRESHOLD;    // Basis-Command-Value
//  cmd_16_buffer |= LOW_BATT_THLD_2_2_V;         // not used
    cmd_16_buffer |= TXBIT_SYNC;                  // Enable TX Bit Syncronisation
//  cmd_16_buffer |= DISABLE_WAKEUP_TIMER_CAL;    // not disabled

    SPI_Config_CMD_16Bit( cmd_16_buffer );    // Writing the command to the SPI-Interface

/*----------------------------------------------------------------------------*/
/*  Init_RF_Power_Management_Register                                         */
//     - das Sleep-Kommando funktioniert nur, wenn hier der Auto-Mode aktiviert ist
//     - das wake-up-Kommando bisher berhaupt nicht und ist auch nicht weiter
//       dokumentiert
//     - der WakeUp-Mode ist auch nicht dokumentiert
//     - beim Schreiben auf die SPI-Schnittstelle ist "nIRQ" vllig irrelevant
//       da dieser eigentlich DatenClockAusgang erst mit diesem Befehl hier
//       berhaupt aktiv wird --> Beispielsoftware nicht korrekt
/*----------------------------------------------------------------------------*/
  cmd_16_buffer  = CONFIG_PWR_CMD;         // Basis-Command-Value
//  cmd_16_buffer |= CLK_PIN;                // Disable ClockPin, not used for MCU
//  cmd_16_buffer |= WAKE_UP_TIMER;          // Enable/set WakeUpTimer
//  cmd_16_buffer |= LOW_BATT_DET;           // Enable Low Battery Detection
  cmd_16_buffer |= POWER_AMP;              // Activate Power Amplifier
  cmd_16_buffer |= SYNTHESSIZER;           // Activate Synthesizer
  cmd_16_buffer |= CRYSTAL_OSC;            // Activate Crystal Oscillator 
//    cmd_16_buffer |= AUTO_PWR_AMP;           // Setting AMP to Auto-Enable/Disable 
//    cmd_16_buffer |= AUTO_PWR_SYN_OSC;       // Setting Synthesizer and Oscillator to Auto-En-/Disable

    SPI_Config_CMD_16Bit( cmd_16_buffer );   // Writing the command to the SPI-Interface
}


/*----------------------------------------------------------------------------*/
/*    Subfunctions                                                            */
/*----------------------------------------------------------------------------*/

/******************************************************************************/
/*         bertragungsfunktion fr die Initialisierung des Sendmoduls        */
/*                                                                            */                
/*         bertragungsfunktion um die Konfigurationskommandos ber die       */
/*         ( nachgebildete )SPI-Schnittstelle an das Modul zu bertragen.     */                
/*                                                                            */                
/*         Aufruf erfolgt fr jedes Konfigurationsregister zum Abschluss      */                
/*         der zugehrigen Konfigurationsfunktion.                            */                
/*                                                                            */                
/*         Die einzelnen Bits des Datenbytes werden mit der 0->1-Flanke       */                
/*         von SCK bernommen.                                                */                
/*                                                                            */                
/*         nSel muss zum Schreiben auf die SPI-Schnittstelle aktiv (low)sein. */                
/*                                                                            */                
/*         nIRQ reagiert hier berhaupt nicht, da er eigentlich ein high-     */                
/*         aktiver DataClockAusgang ist, und nur die Datenbernahme am FSK    */                
/*         Dateneingang fr die zu sendenden Daten ist.                       */                
/*                                                                            */                
/* Autor: Hr.JSchroeder@web.de          01/2012                                      */                
/******************************************************************************/
void SPI_Config_CMD_16Bit ( int SPI_CMD_16Bit){
char i=16;
nCS_low();
    for(i=0;i<16;i++){
      if( SPI_CMD_16Bit & BITF ){ // ...if most significant bit in SPI_CMD_16Bit = '1'
        SDI_high();               // set SDI-Port '1' 
        }else{
        SDI_low();                // set SDI-Port '0'
      }

      SCK_high();                 //  Clock  0 -> 1, Datenbernahme
      SCK_low();                  //  Clock  1 -> 0

      SPI_CMD_16Bit <<= 1;        // shift left ( next bit as most significant bit ...)
    } // end for ...
nCS_high();
}
