#ifndef RFM02_TRANS_h
#define RFM02_TRANS_h

/******************************************************************************/
/*         RFM02_Transmitter  Defines      falls nicht in defines.h           */
/******************************************************************************/

/******************************************************************************/
/*    Pin Description                                                         */
/*                                                                            */
/*    MSP-F2013    Direction   RMF02-Module    Function  (MSP)                */
/*                                                                            */
/*    P1IN (IR)     <---       /IRQ            Inport for the IRQ comming     */
/*    P1OUT1.1      --->       FSK             Output for the data            */
/*    P1OUT1.2      --->       /CS             Output for the Chip-Select     */
/*    P1OUT2.7      --->       SLK             Clock for the SPI-Interface    */
/*    P1OUT2.6      --->       SDI       Output (MOSI) for the SPI-Data-Input */
/*                                                                            */
/******************************************************************************/


/*    Control Register                                                        */
/******************************************************************************/
/*    RF-Config-Register  8080hex      --> For 430MHz-Band , b1(0) b0(1) <--  */
/*                                                                            */
/*    Bits:  15  14  13  12  11  10   9   8   7   6   5   4   3   2   1   0   */
/*            1   0   0  b1  b0  d2  d1  d0  x3  x2  x1  x0  ms  m2  m1  m0   */
/*                                                                            */
/*    Frequency Deviation [kHz]:  m2  m1  m0   value                          */
/*                                 0   0   0    30                            */
/*                                 0   0   1    60                            */
/*                                 0   1   0    90                            */
/*                                 0   1   1   120                            */
/*                                 1   0   0   150                            */
/*                                 1   0   1   180                            */
/*                                 1   1   0   210                            */
/*                                                                            */
/*    Modulation Polarity:         ms  value                                  */
/*                                  0   +180                                 */
/*                                  1   -180                                 */
/*                                                                            */
/*    Crystal Load Capacity:       x3  x2  x1  x0   value                     */
/*                                  0   0   0   0   8.5 pF                    */
/*                                  0   0   0   1   9.0 pF                    */
/*                                  0   0   1   0   9.5 pF                    */
/*                                  0   0   1   1   10  pF                    */
/*                                  .   .   .   .                             */
/*                                  .   .   .   .                             */
/*                                  .   .   .   .                             */
/*                                  1   1   1   1   16.0 pF                   */
/*                                                                            */
/*    Frequency of Pin CLK:        d2  d1  d0   value                         */
/*                                  0   0   0   1    MHz                      */
/*                                  0   0   1   1.25 MHz                      */
/*                                  0   1   0   1.66 MHz                      */
/*                                  0   1   1   2.0  MHz                      */
/*                                  1   0   0   2.5  MHz                      */
/*                                  1   0   1   3.33 MHz                      */
/*                                  1   1   0   5    MHz                      */
/*                                  1   1   1   10   MHz                      */
/*                                                                            */
/*    If the CLK-Pin is not usesd to clock an external mikrocontroller        */
/*    set the dc-Bit in the Power Management Register.                        */
/*                                                                            */
/*    Band Selection:                   b1  b0  value                         */
/*                                      0   1   433 MHz                       */
/*                                      1   0   868 MHz                       */
/*                                      1   1   915 MHz                       */
/*                                                                            */
/******************************************************************************/

#define CONFIG_CMD          0x8000

/*    Frequency Deviation [kHz]:  m2  m1  m0   value                          */
#define FREQ_DEV_30kHz      0x00       // 0 0 0 0 0 0 0 0
#define FREQ_DEV_60kHz      0x01
#define FREQ_DEV_90kHz      0x02
#define FREQ_DEV_120kHz     0x03
#define FREQ_DEV_150kHz     0x04
#define FREQ_DEV_180kHz     0x05
#define FREQ_DEV_210kHz     0x06       // 0 0 0 0 0 1 1 0

/*    Modulation Polarity:         ms  value                                  */
#define MOD_POLTY_180_NEG          0x08  // 0 0 0 0 1 0 0 0

/*    Crystal Load Capacity:       x3  x2  x1  x0   value                     */
#define CRYSTAL_LD_CAP_08_5PF       0x00            // 8,5pF
#define CRYSTAL_LD_CAP_09_0PF       0x10            // ...
#define CRYSTAL_LD_CAP_09_5PF       0x20
#define CRYSTAL_LD_CAP_10_0PF       0x30
#define CRYSTAL_LD_CAP_10_5PF       0x40
#define CRYSTAL_LD_CAP_11_0PF       0x50
#define CRYSTAL_LD_CAP_11_5PF       0x60
#define CRYSTAL_LD_CAP_12_0PF       0x70
#define CRYSTAL_LD_CAP_12_5PF       0x80
#define CRYSTAL_LD_CAP_13_0PF       0x90
#define CRYSTAL_LD_CAP_13_5PF       0xA0
#define CRYSTAL_LD_CAP_14_0PF       0xB0
#define CRYSTAL_LD_CAP_14_5PF       0xC0
#define CRYSTAL_LD_CAP_15_0PF       0xD0
#define CRYSTAL_LD_CAP_15_5PF       0xE0
#define CRYSTAL_LD_CAP_16_0PF       0xF0

/*    Frequency of Pin CLK:      d2  d1  d0   value                         */
#define CLK_PIN_FREQ_1_00MHZ        0x0000      // 0 0 0 0 0 0 0 0
#define CLK_PIN_FREQ_1_25MHZ        0x0100
#define CLK_PIN_FREQ_1_66MHZ        0x0200      // ...
#define CLK_PIN_FREQ_2_00MHZ        0x0300
#define CLK_PIN_FREQ_2_50MHZ        0x0400
#define CLK_PIN_FREQ_3_33MHZ        0x0500
#define CLK_PIN_FREQ_5_00MHZ        0x0600
#define CLK_PIN_FREQ_10_00MHZ       0x0700     // 0 0 0 0 0 1 1 1 0 0 0 0 0 0 0 0

/*    Band Selection:             b1  b0    value ...                        */

#define BAND_SELECT_360MHz          0x0000
#define BAND_SELECT_433MHz          0x0800
#define BAND_SELECT_868MHz          0x1000
#define BAND_SELECT_915MHz          0x1800



/******************************************************************************/
/*    Power-Management-Register  C000hex                                      */
/*                                                                            */
/*    Bits:  15  14  13  12  11  10   9   8   7   6   5   4   3   2   1   0   */
/*            1   1   0   0   0   0   0   0  a1  a0  ex  es  ea  eb  et  dc   */
/*                                                                            */
/*    dc  -   disable CLK  at  Pin CLK, if not used for the Control MCU       */
/*    et  -   enable wake-up-timer                                            */
/*    eb  -   enable low battery detection hardware                           */
/*    ea  -   enable power amplifier                                          */
/*    es  -   enable synthesizer                                              */
/*    ex  -   enable crystal oscillator                                       */
/*                                                                            */
/*    a0  -   if set, power amplifier is enabled by the data transmit command */
/*            and disabled via the sleep command                              */
/*                                                                            */
/*    a1  -   if set, crystal oscillator and synthesizer are enabled via the  */
/*            transmit command, and disabled via the sleep command            */
/******************************************************************************/

#define CONFIG_PWR_CMD           0xC000

#define CLK_PIN           0x01
#define WAKE_UP_TIMER     0x02
#define LOW_BATT_DET      0x04
#define POWER_AMP         0x08
#define SYNTHESSIZER      0x10
#define CRYSTAL_OSC       0x20
#define AUTO_PWR_AMP      0x40
#define AUTO_PWR_SYN_OSC  0x80

/******************************************************************************/
/*    RF-Frequency-Adjust-Register  A7D0hex                                   */
/*                                                                            */
/*    Bits:  15  14  13  12  11  10   9   8   7   6   5   4   3   2   1   0   */
/*            1   0   1   0  f11 f10 f9  f8  f7  f6  f5  f4  f3  f2  f1  f0   */
/*                                                                            */
/*     433band: f = 430 + F * 0.0025 MHz                                      */
/*     868band: f = 860 + F * 0.0050 MHz                                      */
/*     915band: f = 900 + F * 0.0075 MHz                                      */
/*                                                                            */
/*     value ranges from 0..4096                                              */
/*                                                                            */
/*     --> f can be set from 430.0000 ..  440.2400 MHz    (in 433MHz Band)    */
/*                                                                            */
/*                                                                            */
/******************************************************************************/
#define CONFIG_RF_FREQUENY_CMD    0xA000

// Value for frequency must be calculated for the define
// Value for 440.2400 MHz
#define RF_FRQUENCY_439_9000_MHZ  0x0F3F   // max value
#define RF_FRQUENCY_430_0000_MHZ  0x0060  // min. value

/******************************************************************************/
/*    Baudrate-Adjust-Register  C800hex                                       */
/*                                                                            */
/*    Bits:  15  14  13  12  11  10   9   8   7   6   5   4   3   2   1   0   */
/*            1   1   0   0   1   0   0   0  r7  r6  r5  r4  r3  r2  r1  r0   */
/*                                                                            */
/*     Baud Rate = 10000000/29/(R+1)                                          */
/*                                                                            */
/*     R ranges from 0..255                                                   */
/*                                                                            */
/*     --> Baud Rate can be set from 1,35 kBit/s  ..  344,8 kBit/s            */
/*                                                                            */
/*     Common values range from 9600 Bit/s .. 115.000 Bit/s                   */
/******************************************************************************/
#define CONFIG_BAUD_RATE_CMD           0xC800

// Value for baud rate must be calculated for the define
// Value for 38.400 bps  is 7.97988  --> 8

#define BAUD_RATE_445_000_BPS 0x00
#define BAUD_RATE_172_000_BPS 0x01
#define BAUD_RATE_115_000_BPS 0x02
#define BAUD_RATE_38_400_BPS  0x08
#define BAUD_RATE_19_200_BPS  0x11
#define BAUD_RATE_04_800_BPS  0x47


/******************************************************************************/
/*    RF-Power-Register  B0hex                                                */
/*                                                                            */
/*    Bits:   7   6   5   4   3   2   1   0                                   */
/*            1   0   1   1   0  p2  p1  p0                                   */
/*                                                                            */
/*     RF-Power = 9 dBm - P - 1                                               */
/*                                                                            */
/*     P ranges from 0..7                                                     */
/*                                                                            */
/*     --> RF-Transmit-Power can be set from 1 .. 8 dBm                       */
/*                                                                            */
/******************************************************************************/
#define CONFIG_RF_PWR_CMD     0x00B0

#define RF_PWR_8DBM    0x00   // Pmax
// ...
// ...
#define RF_PWR_1DBM    0x07   // Pmin

/******************************************************************************/
/*    LowBattDetect and TxD-sync-Bit-Register  C200hex                        */
/*                                                                            */
/*    Bits:  15  14  13  12  11  10   9   8   7   6   5   4   3   2   1   0   */
/*            1   1   0   0   0   0   1   0 dwc   0 ebs  t4  t3  t2  t1  t0   */
/*                                                                            */
/*     Threshold Voltage is set by t4..t0 with Vlb = 2.2 V + T * 0.1 V        */
/*                                                                            */
/*     Threshold ranges from 2.2V .. 5.3V                                     */
/*                                                                            */
/*     ebs  -  Enable TX Bit synchronisation function                         */
/*                                                                            */
/*     dwc  -  Disable wake-up-timer periodical calibration                   */
/*                                                                            */
/******************************************************************************/
#define CONFIG_LOW_BATT_TRESHOLD  0xC200

#define LOW_BATT_THLD_2_2_V       0x00
#define TXBIT_SYNC                0x20
#define DISABLE_WAKEUP_TIMER_CAL  0x80

/******************************************************************************/
/*         Function Prototypes                                                */
/******************************************************************************/

void Init_RFM02_Transmit_Module_Continous_Mode (void);
void SPI_Config_CMD_16Bit (int);

#endif
